####################################################################################################
#
#   (c) Copyright Motorola 2019. All rights reserved.
#   Motorola Confidential Proprietary
#   Contains confidential proprietary information of Motorola Mobility LLC.
#   Reverse engineering is prohibited.
#   The copyright notice does not imply publication.
#
####################################################################################################
import click
from davros_device_server.davros_device_server import AutoUpdater

__help__ = """Davros server auto update.
This package is used to automatically update Davros slave server.
https://www.davros.mot.com"""

d = AutoUpdater()


@click.group("davros-device-server", help=__help__)
def davros_device_server():
    click.echo("Davros device server.")


@davros_device_server.command(help="Starts Davros server and Auto updater instance.")
@click.option(
    "--no-updater",
    is_flag=True,
    help="Run the latest version available without updating it after it is "
    "running. Use when you need to use the server without interruption "
    "for a critical task.",
)
@click.option(
    "--force",
    is_flag=True,
    help="Only valid with the 'no-updater' option. If a Davros instance is "
    "running, stops it and start a newer.",
)
def start(no_updater, force):
    if no_updater:
        d.start_server(force)
    else:
        if not d.start_autoupdater(force):
            click.echo(
                "Davros server is already running, use the '--force' flag to kill it and start a new instance"
            )


@davros_device_server.command(help="Stops the Auto updater instance.")
@click.option(
    "--force",
    is_flag=True,
    help="Forcefully kills Davros server (only recommended when it is stuck).",
)
def stop(force):
    d.stop_autoupdater(force)
