###################################################################################################
#
#   (c) Copyright Motorola 2018. All rights reserved.
#   Motorola Confidential Proprietary
#   Contains confidential proprietary information of Motorola Mobility LLC.
#   Reverse engineering is prohibited.
#   The copyright notice does not imply publication.
#
###################################################################################################

import sys
import os

PLATFORM = {"linux": ["linux2", "linux"], "windows": ["win32", "cygwin"]}


def windows():
    return sys.platform in PLATFORM["windows"]


def which(program):
    def is_exe(p):
        return os.path.isfile(p) and os.access(p, os.X_OK)
    if windows():
        program = program + '.exe'
    fpath, fname = os.path.split(program)
    if fpath:
        if is_exe(program):
            return program
    else:
        for path in os.environ["PATH"].split(os.pathsep):
            exe_file = os.path.join(path, program)
            if is_exe(exe_file):
                return exe_file
    return None


def user_path():
    """
    Current machine user path.
    :return String: Default user path
    """
    return os.path.expanduser("~")


class ServiceExit(Exception):
    """
    Custom exception which is used to trigger the clean exit
    of all running threads and the main program.
    """


def service_shutdown(signum, frame):
    raise ServiceExit
